@@ -13,14 +13,16 @@ import os
 import sys
 import unittest
 from inspect import isfunction, ismethod
-from nose.case import Failure, FunctionTestCase, MethodTestCase
+from nose.case import FunctionTestCase, MethodTestCase
+from nose.failure import Failure
 from nose.config import Config
 from nose.importer import Importer, add_path, remove_path
 from nose.selector import defaultSelector, TestAddress
 from nose.util import cmp_lineno, getpackage, isclass, isgenerator, ispackage, \
-    match_last, resolve_name
+    match_last, resolve_name, transplant_func, transplant_class
 from nose.suite import ContextSuiteFactory, ContextList, LazySuite
 
+
 log = logging.getLogger(__name__)
 #log.setLevel(logging.DEBUG)
 
@@ -128,7 +130,9 @@ class TestLoader(unittest.TestLoader):
         entries = os.listdir(path)
         entries.sort(lambda a, b: match_last(a, b, self.config.testMatch))
         for entry in entries:
-            if entry.startswith('.') or entry.startswith('_'):
+            # this hard-coded initial-dot test will be removed:
+            # http://code.google.com/p/python-nose/issues/detail?id=82
+            if entry.startswith('.'):
                 continue
             entry_path = op_abspath(op_join(path, entry))
             is_file = op_isfile(entry_path)
@@ -139,6 +143,10 @@ class TestLoader(unittest.TestLoader):
             else:
                 is_dir = op_isdir(entry_path)
                 if is_dir:
+                    # this hard-coded initial-underscore test will be removed:
+                    # http://code.google.com/p/python-nose/issues/detail?id=82
+                    if entry.startswith('_'):
+                        continue
                     wanted = self.selector.wantDirectory(entry_path)
             is_package = ispackage(entry_path)
             if wanted:
@@ -159,16 +167,13 @@ class TestLoader(unittest.TestLoader):
                     # Another test dir in this one: recurse lazily
                     yield self.suiteClass(
                         lambda: self.loadTestsFromDir(entry_path))
-        # Catch TypeError and AttributeError exceptions here and discard
-        # them: the default plugin manager, NoPlugins, will raise TypeError
-        # on generative calls.
+        tests = []
+        for test in plugins.loadTestsFromDir(path):
+            tests.append(test)
+        # TODO: is this try/except needed?
         try:
-            tests = []
-            for test in plugins.loadTestsFromDir(path):
-                tests.append(test)
-            yield self.suiteClass(tests)
-        except (TypeError, AttributeError):
-            pass
+            if tests:
+                yield self.suiteClass(tests)
         except (KeyboardInterrupt, SystemExit):
             raise
         except:
@@ -295,18 +300,8 @@ class TestLoader(unittest.TestLoader):
         for path in paths:
             tests.extend(self.loadTestsFromDir(path))
             
-        # Catch TypeError and AttributeError exceptions here and discard
-        # them: the default plugin manager, NoPlugins, will raise TypeError
-        # on generative calls.
-        try:
-            for test in self.config.plugins.loadTestsFromModule(module):
-                tests.append(test)
-        except (TypeError, AttributeError):
-            pass
-        except (KeyboardInterrupt, SystemExit):
-            raise
-        except:
-            tests.append(Failure(*sys.exc_info()))
+        for test in self.config.plugins.loadTestsFromModule(module):
+            tests.append(test)
 
         return self.suiteClass(ContextList(tests, context=module))
     
@@ -341,6 +336,11 @@ class TestLoader(unittest.TestLoader):
             if addr.call:
                 name = addr.call
             parent, obj = self.resolve(name, module)
+            if (isclass(parent)
+                and getattr(parent, '__module__', None) != module.__name__):
+                parent = transplant_class(parent, module.__name__)
+                obj = getattr(parent, obj.__name__)
+            log.debug("parent %s obj %s module %s", parent, obj, module)
             if isinstance(obj, Failure):
                 return suite([obj])
             else:
@@ -426,18 +426,8 @@ class TestLoader(unittest.TestLoader):
         """
         cases = []
         plugins = self.config.plugins
-        # Catch TypeError and AttributeError exceptions here and discard
-        # them: the default plugin manager, NoPlugins, will raise TypeError
-        # on generative calls.
-        try:
-            for case in plugins.loadTestsFromTestCase(testCaseClass):
-                cases.append(case)
-        except (TypeError, AttributeError):
-            pass
-        except (KeyboardInterrupt, SystemExit):
-            raise
-        except:
-            cases.append(Failure(*sys.exc_info()))
+        for case in plugins.loadTestsFromTestCase(testCaseClass):
+            cases.append(case)
         # For efficiency in the most common case, just call and return from
         # super. This avoids having to extract cases and rebuild a context
         # suite when there are no plugin-contributed cases.
@@ -463,35 +453,21 @@ class TestLoader(unittest.TestLoader):
             return sel.wantMethod(item)
         cases = [self.makeTest(getattr(cls, case), cls)
                  for case in filter(wanted, dir(cls))]
-        # Catch TypeError and AttributeError exceptions here and discard
-        # them: the default plugin manager, NoPlugins, will raise TypeError
-        # on generative calls.
-        try:
-            for test in self.config.plugins.loadTestsFromTestClass(cls):
-                cases.append(test)
-        except (TypeError, AttributeError):
-            pass
-        except (KeyboardInterrupt, SystemExit):
-            raise
-        except:
-            cases.append(Failure(*sys.exc_info()))
+        for test in self.config.plugins.loadTestsFromTestClass(cls):
+            cases.append(test)
         return self.suiteClass(ContextList(cases, context=cls))
 
     def makeTest(self, obj, parent=None):
         """Given a test object and its parent, return a test case
         or test suite.
         """
-        # Catch TypeError and AttributeError exceptions here and discard
-        # them: the default plugin manager, NoPlugins, will raise TypeError
-        # on generative calls.
         plug_tests = []
+        for test in self.config.plugins.makeTest(obj, parent):
+            plug_tests.append(test)
+        # TODO: is this try/except needed?
         try:
-            for test in self.config.plugins.makeTest(obj, parent):
-                plug_tests.append(test)
             if plug_tests:
                 return self.suiteClass(plug_tests)
-        except (TypeError, AttributeError):
-            pass
         except (KeyboardInterrupt, SystemExit):
             raise
         except:
@@ -499,7 +475,9 @@ class TestLoader(unittest.TestLoader):
         
         if isinstance(obj, unittest.TestCase):
             return obj
-        elif isclass(obj):            
+        elif isclass(obj):
+            if parent and obj.__module__ != parent.__name__:
+                obj = transplant_class(obj, parent.__name__)
             if issubclass(obj, unittest.TestCase):
                 return self.loadTestsFromTestCase(obj)
             else:
@@ -515,6 +493,8 @@ class TestLoader(unittest.TestLoader):
                 else:
                     return MethodTestCase(obj)
         elif isfunction(obj):
+            if parent and obj.__module__ != parent.__name__:
+                obj = transplant_func(obj, parent.__name__)
             if isgenerator(obj):
                 return self.loadTestsFromGenerator(obj, parent)
             else:
