@@ -48,7 +48,7 @@ import logging
 import os
 import sys
 from warnings import warn
-from nose.case import Failure
+from nose.failure import Failure
 from nose.plugins.base import IPluginInterface
 
 __all__ = ['DefaultPluginManager', 'PluginManager', 'EntryPointPluginManager',
@@ -128,15 +128,15 @@ class PluginProxy(object):
             result = None
             try:
                 result = meth(*arg, **kw)
+                if result is not None:
+                    for r in result:
+                        yield r
             except (KeyboardInterrupt, SystemExit):
                 raise
             except:
                 exc = sys.exc_info()
                 yield Failure(*exc)
-            else:
-                if result is not None:
-                    for r in result:
-                        yield r
+                continue
 
     def simple(self, *arg, **kw):
         """Call all plugins, returning the first non-None result.
@@ -162,6 +162,44 @@ class PluginProxy(object):
         return suite, names
 
 
+class NoPlugins(object):
+    """Null Plugin manager that has no plugins."""
+    interface = IPluginInterface
+    def __init__(self):
+        self.plugins = ()
+
+    def __iter__(self):
+        return ()
+
+    def _doNothing(self, *args, **kwds):
+        pass
+
+    def _emptyIterator(self, *args, **kwds):
+        return ()
+
+    def __getattr__(self, call):
+        method = getattr(self.interface, call)
+        if getattr(method, "generative", False):
+            return self._emptyIterator
+        else:
+            return self._doNothing
+
+    def addPlugin(self, plug):
+        raise NotImplementedError()
+
+    def addPlugins(self, plugins):
+        raise NotImplementedError()
+
+    def configure(self, options, config):
+        pass
+
+    def loadPlugins(self):
+        pass
+
+    def sort(self, cmpf=None):
+        pass
+
+
 class PluginManager(object):
     """Base class for plugin managers. Does not implement loadPlugins, so it
     may only be used with a static list of plugins.
@@ -358,20 +396,31 @@ class RestrictedPluginManager(DefaultPluginManager):
     an excluded method will be removed from the manager's plugin list
     after plugins are loaded.
     """
-    def __init__(self, plugins=(), exclude=()):
+    def __init__(self, plugins=(), exclude=(), load=True):
         DefaultPluginManager.__init__(self, plugins)
+        self.load = load
         self.exclude = exclude
-
+        self.excluded = []
+        self._excludedOpts = None
+        
+    def excludedOption(self, name):
+        if self._excludedOpts is None:
+            from optparse import OptionParser
+            self._excludedOpts = OptionParser(add_help_option=False)
+            for plugin in self.excluded:
+                plugin.options(self._excludedOpts, env={})
+        return self._excludedOpts.get_option('--' + name)
+        
     def loadPlugins(self):
-        DefaultPluginManager.loadPlugins(self)
+        if self.load:
+            DefaultPluginManager.loadPlugins(self)
         allow = []
         for plugin in self.plugins:
             ok = True
             for method in self.exclude:
                 if hasattr(plugin, method):
-                    warn("Exclude plugin %s: implements %s" % (plugin, method),
-                         RuntimeWarning)
                     ok = False
+                    self.excluded.append(plugin)
                     break
             if ok:
                 allow.append(plugin)
