@@ -74,6 +74,15 @@ class TestUtils(unittest.TestCase):
             def test_two(self):
                 pass
         
+        class CustomTestType(type):
+            pass
+        class CustomTC(unittest.TestCase):
+            __metaclass__ = CustomTestType
+            def test_one(self):
+                pass
+            def test_two(self):
+                pass
+        
         foo_funct = case.FunctionTestCase(baz)
         foo_functu = unittest.FunctionTestCase(baz)
 
@@ -93,12 +102,41 @@ class TestUtils(unittest.TestCase):
         # missed test plugin must do
         self.assertEqual(test_address(FooTC('test_one')),
                          (me, __name__, 'FooTC.test_one'))
+        self.assertEqual(test_address(CustomTC('test_one')),
+                         (me, __name__, 'CustomTC.test_one'))
         self.assertEqual(test_address(foo_funct),
                          (me, __name__, 'baz'))
         self.assertEqual(test_address(foo_functu),
                          (me, __name__, 'baz'))
         self.assertEqual(test_address(foo_mtc),
                          (me, __name__, 'Foo.bar'))
+    
+    def test_isclass_detects_classes(self):
+        class TC(unittest.TestCase):
+            pass
+        class TC_Classic:
+            pass
+        class TC_object(object):
+            pass
+        # issue153 -- was not detecting custom typed classes...
+        class TCType(type):
+            pass
+        class TC_custom_type(object):
+            __metaclass__ = TCType
+        class TC_unittest_custom_type(unittest.TestCase):
+            __metaclass__ = TCType
+        
+        assert util.isclass(TC), "failed to detect %s as class" % TC
+        assert util.isclass(TC_Classic), "failed to detect %s as class" % TC_Classic
+        assert util.isclass(TC_object), "failed to detect %s as class" % TC_object
+        assert util.isclass(TC_custom_type), "failed to detect %s as class" % TC_custom_type
+        assert util.isclass(TC_unittest_custom_type), "failed to detect %s as class" % TC_unittest_custom_type
+        
+    def test_isclass_ignores_nonclass_things(self):
+        anint = 1
+        adict = {}
+        assert not util.isclass(anint), "should have ignored %s" % type(anint)
+        assert not util.isclass(adict), "should have ignored %s" % type(adict)
 
     def test_tolist(self):
         tolist = util.tolist
